@@ -20,7 +20,6 @@ from sklearn.metrics import mean_squared_error
 from nsepy import get_history
 import yfinance as yfin
 
-yfin.pdr_override()
 #from .constant import STOCK_LIST
 
 def memoize( func ):
@@ -80,10 +79,11 @@ def getHistoricStockPricesFromYahoo( stock_name, start_date = None, end_date = N
     '''
 
     try:
+        yfin.pdr_override()
         if end_date is None: end_date = datetime.datetime.today()
         if start_date is None: start_date = end_date + datetime.timedelta( days = -1* 365 )
 
-        hist_prices = pdr.get_data_yahoo(name = stock_name, start = start_date, end = end_date)
+        hist_prices = pdr.get_data_yahoo(tickers = 'MARUTI.NS', start = start_date, end = end_date)
         return hist_prices
         
     except:
